@@ -112,7 +112,7 @@ public:
      * @param input the digital input
      * @return the analog output value
      */
-    double getOutput(unsigned int input) const;
+    double getOutput(unsigned int input, bool saturate=false) const;
 };
 
 } // namespace reSIDfp
