@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- * Copyright 2011-2020 Leandro Nini <drfiemost@users.sourceforge.net>
+ * Copyright 2011-2024 Leandro Nini <drfiemost@users.sourceforge.net>
  * Copyright 2007-2010 Antti Lankila
  * Copyright 2004,2010 Dag Lem <resid@nimrod.no>
  *
@@ -23,12 +23,9 @@
 #ifndef FILTER6581_H
 #define FILTER6581_H
 
-#include "siddefs-fp.h"
-
-#include <memory>
-
 #include "Filter.h"
 #include "FilterModelConfig6581.h"
+#include "Integrator6581.h"
 
 #include "sidcxx11.h"
 
@@ -108,7 +105,7 @@ class Integrator6581;
  *     |   |   |   v1       |    |   |                               |
  * D0  |   |   |   \ ---R8--+    |   |   +---------------------------+
  *     |   |   |   |             |   |   |
- *     R6  R6  R6  R6            R6  R6  R6
+ *     R6  R6  R6  R6            R6* R6* R6*
  *     |   |   |   | $18         |   |   |  $18
  *     |    \  |   | D7: 1=open   \   \   \ D6 - D4: 0=open
  *     |   |   |   |             |   |   |
@@ -143,6 +140,7 @@ class Integrator6581;
  *
  *     R2  ~  2.0*R1
  *     R6  ~  6.0*R1
+ *     R6* ~  1.07*R6
  *     R8  ~  8.0*R1
  *     R24 ~ 24.0*R1
  *
@@ -322,102 +320,49 @@ class Integrator6581;
 class Filter6581 final : public Filter
 {
 private:
-    const unsigned short* f0_dac;
-
-    unsigned short** mixer;
-    unsigned short** summer;
-    unsigned short** gain;
-
-    const int voiceScaleS11;
-    const int voiceDC;
-
     /// VCR + associated capacitor connected to highpass output.
-    std::unique_ptr<Integrator6581> const hpIntegrator;
+    Integrator6581 hpIntegrator;
 
     /// VCR + associated capacitor connected to bandpass output.
-    std::unique_ptr<Integrator6581> const bpIntegrator;
+    Integrator6581 bpIntegrator;
+
+    const unsigned short* f0_dac;
 
 protected:
     /**
      * Set filter cutoff frequency.
      */
-    void updatedCenterFrequency() override;
+    void updateCenterFrequency() override;
 
-    /**
-     * Set filter resonance.
-     *
-     * In the MOS 6581, 1/Q is controlled linearly by res.
-     */
-    void updateResonance(unsigned char res) override { currentResonance = gain[~res & 0xf]; }
-
-    void updatedMixing() override;
+    int solveIntegrators() override;
 
 public:
     Filter6581() :
-        f0_dac(FilterModelConfig6581::getInstance()->getDAC(0.5)),
-        mixer(FilterModelConfig6581::getInstance()->getMixer()),
-        summer(FilterModelConfig6581::getInstance()->getSummer()),
-        gain(FilterModelConfig6581::getInstance()->getGain()),
-        voiceScaleS11(FilterModelConfig6581::getInstance()->getVoiceScaleS11()),
-        voiceDC(FilterModelConfig6581::getInstance()->getVoiceDC()),
-        hpIntegrator(FilterModelConfig6581::getInstance()->buildIntegrator()),
-        bpIntegrator(FilterModelConfig6581::getInstance()->buildIntegrator())
-    {
-        input(0);
-    }
+        Filter(*FilterModelConfig6581::getInstance()),
+        hpIntegrator(*FilterModelConfig6581::getInstance()),
+        bpIntegrator(*FilterModelConfig6581::getInstance()),
+        f0_dac(FilterModelConfig6581::getInstance()->getDAC(0.5))
+    {}
 
-    ~Filter6581();
-
-    unsigned short clock(int voice1, int voice2, int voice3) override;
-
-    void input(int sample) override { ve = (sample * voiceScaleS11 * 3 >> 11) + mixer[0][0]; }
+    ~Filter6581() override;
 
     /**
      * Set filter curve type based on single parameter.
      *
-     * @param curvePosition 0 .. 1, where 0 sets center frequency high ("light") and 1 sets it low ("dark"), default is 0.5
+     * @param curvePosition 0 .. 1, where 0 sets center frequency high ("bright") and 1 sets it low ("dark").
+     *                      Default is 0.5
      */
     void setFilterCurve(double curvePosition);
+
+    /**
+     * Set filter offset and range based on single parameter.
+     *
+     * @param adjustment 0 .. 1, where 0 sets center frequency low ("dark"), 1 sets it high ("bright").
+     *                   This also affects the range. Default is 0.5
+     */
+    void setFilterRange(double adjustment);
 };
 
 } // namespace reSIDfp
 
-#if RESID_INLINING || defined(FILTER6581_CPP)
-
-#include "Integrator6581.h"
-
-namespace reSIDfp
-{
-
-RESID_INLINE
-unsigned short Filter6581::clock(int voice1, int voice2, int voice3)
-{
-    voice1 = (voice1 * voiceScaleS11 >> 15) + voiceDC;
-    voice2 = (voice2 * voiceScaleS11 >> 15) + voiceDC;
-    // Voice 3 is silenced by voice3off if it is not routed through the filter.
-    voice3 = (filt3 || !voice3off) ? (voice3 * voiceScaleS11 >> 15) + voiceDC : 0;
-
-    int Vi = 0;
-    int Vo = 0;
-
-    (filt1 ? Vi : Vo) += voice1;
-    (filt2 ? Vi : Vo) += voice2;
-    (filt3 ? Vi : Vo) += voice3;
-    (filtE ? Vi : Vo) += ve;
-
-    Vhp = currentSummer[currentResonance[Vbp] + Vlp + Vi];
-    Vbp = hpIntegrator->solve(Vhp);
-    Vlp = bpIntegrator->solve(Vbp);
-
-    if (lp) Vo += Vlp;
-    if (bp) Vo += Vbp;
-    if (hp) Vo += Vhp;
-
-    return currentGain[currentMixer[Vo]];
-}
-
-} // namespace reSIDfp
-
-#endif
-
 #endif
