@@ -1,7 +1,7 @@
 /*
  * This file is part of libsidplayfp, a SID player engine.
  *
- * Copyright 2011-2022 Leandro Nini <drfiemost@users.sourceforge.net>
+ * Copyright 2011-2024 Leandro Nini <drfiemost@users.sourceforge.net>
  * Copyright 2007-2010 Antti Lankila
  * Copyright 2004,2010 Dag Lem
  *
@@ -23,13 +23,13 @@
 #include "FilterModelConfig.h"
 
 #include <vector>
+#include <cstdint>
 
 namespace reSIDfp
 {
 
 FilterModelConfig::FilterModelConfig(
     double vvr,
-    double vdv,
     double c,
     double vdd,
     double vth,
@@ -37,21 +37,23 @@ FilterModelConfig::FilterModelConfig(
     const Spline::Point *opamp_voltage,
     int opamp_size
 ) :
-    voice_voltage_range(vvr),
-    voice_DC_voltage(vdv),
     C(c),
     Vdd(vdd),
     Vth(vth),
-    Ut(26.0e-3),
-    uCox(ucox),
     Vddt(Vdd - Vth),
     vmin(opamp_voltage[0].x),
     vmax(std::max(Vddt, opamp_voltage[0].y)),
     denorm(vmax - vmin),
     norm(1.0 / denorm),
-    N16(norm * ((1 << 16) - 1)),
-    currFactorCoeff(denorm * (uCox / 2. * 1.0e-6 / C))
+    N16(norm * UINT16_MAX),
+    voice_voltage_range(vvr),
+    mixer(new unsigned short[mixer_offset<8>::value]),
+    summer(new unsigned short[summer_offset<5>::value]),
+    volume(new unsigned short[16 * (1 << 16)]),
+    resonance(new unsigned short[16 * (1 << 16)])
 {
+    setUCox(ucox);
+
     // Convert op-amp voltage transfer to 16 bit values.
 
     std::vector<Spline::Point> scaled_voltage(opamp_size);
@@ -73,10 +75,22 @@ FilterModelConfig::FilterModelConfig(
     {
         const Spline::Point out = s.evaluate(x);
         // When interpolating outside range the first elements may be negative
-        double tmp = out.x > 0. ? out.x : 0.;
-        assert(tmp < 65535.5);
-        opamp_rev[x] = static_cast<unsigned short>(tmp + 0.5);
+        opamp_rev[x] = out.x > 0. ? to_ushort(out.x) : 0;
     }
 }
 
+FilterModelConfig::~FilterModelConfig()
+{
+    delete [] mixer;
+    delete [] summer;
+    delete [] volume;
+    delete [] resonance;
+}
+
+void FilterModelConfig::setUCox(double new_uCox)
+{
+    uCox = new_uCox;
+    currFactorCoeff = denorm * (uCox / 2. * 1.0e-6 / C);
+}
+
 } // namespace reSIDfp
