@@ -94,12 +94,6 @@ constexpr uint_least32_t MAX_FILELEN = MAX_MEMORY + 2 + 0x7C;
 /// Minimum load address for real c64 only tunes
 constexpr uint_least16_t SIDTUNE_R64_MIN_LOAD_ADDR = 0x07e8;
 
-SidTuneBase* SidTuneBase::load(const char* fileName, const char **fileNameExt,
-                 bool separatorIsSlash)
-{
-    return load(nullptr, fileName, fileNameExt, separatorIsSlash);
-}
-
 SidTuneBase* SidTuneBase::load(LoaderFunc loader, const char* fileName,
                  const char **fileNameExt, bool separatorIsSlash)
 {
@@ -114,22 +108,6 @@ SidTuneBase* SidTuneBase::load(LoaderFunc loader, const char* fileName,
     return getFromFiles(loader, fileName, fileNameExt, separatorIsSlash);
 }
 
-SidTuneBase* SidTuneBase::read(const uint_least8_t* sourceBuffer, uint_least32_t bufferLen)
-{
-    return getFromBuffer(sourceBuffer, bufferLen);
-}
-
-const SidTuneInfo* SidTuneBase::getInfo() const
-{
-    return info.get();
-}
-
-const SidTuneInfo* SidTuneBase::getInfo(unsigned int songNum)
-{
-    selectSong(songNum);
-    return info.get();
-}
-
 unsigned int SidTuneBase::selectSong(unsigned int selectedSong)
 {
     // Check whether selected song is valid, use start song if not
@@ -362,11 +340,6 @@ void SidTuneBase::createNewFileName(std::string& destString,
 
 // Initializing the object based upon what we find in the specified file.
 
-SidTuneBase* SidTuneBase::getFromFiles(const char* fileName, const char **fileNameExtensions, bool separatorIsSlash)
-{
-    return getFromFiles(nullptr, fileName, fileNameExtensions, separatorIsSlash);
-}
-
 SidTuneBase* SidTuneBase::getFromFiles(LoaderFunc loader, const char* fileName, const char **fileNameExtensions, bool separatorIsSlash)
 {
     buffer_t fileBuf1;
